/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  menu: {
    system: 'System',
    userManagement: 'User Management',
    roleManagement: 'Role Management',
    menuManagement: 'Menu Management',
    tokenManagement: 'Token Management',
    teamManagement: 'Team Management',
    memberManagement: 'Member Management',
    project: 'Project',
    application: 'Application',
    variable: 'Variable',
    setting: 'Settings',
  },
  setting: {
    system: 'System Setting',
    alarm: 'Alarm Setting',
    flinkHome: 'Flink Home',
    flinkCluster: 'Flink Cluster',
    externalLink: 'External Link',
    yarnQueue: 'Yarn Queue',
  },
};
